//#define XERR
#include "densities.ih"

void Densities::writeParameters(std::ostream &out) const
{
    out << 
        "BreastDensities:\n";

    Globals::setWidthPrec(out, 3, 2);

    for (Density const &density: d_densities)
        out << setw(2) << ' ' << density << '\n';

    out.put('\n');
}
